pub struct B8(/* private fields */);Expand description
a type used to represent a field with a specific amount of bits.
Implementations
Sourceimpl B8
impl B8
pub const fn from_fields(fields: B8) -> B8
pub const fn to_fields(x: B8) -> B8
pub const fn try_from_bits( bits: <BitLength<8> as AssociatedStorage>::Storage, ) -> Option<B8>
pub const fn from_bits(bits: <BitLength<8> as AssociatedStorage>::Storage) -> B8
pub const fn to_bits(x: B8) -> <BitLength<8> as AssociatedStorage>::Storage
pub const fn const_eq(a: Self, b: Self) -> bool
Sourceimpl B8
impl B8
Sourcepub const fn new(value: <BitLength<8> as AssociatedStorage>::Storage) -> Self
pub const fn new(value: <BitLength<8> as AssociatedStorage>::Storage) -> Self
creates a new instance of this bitfield type with the given value.
this function panics if the value does not fit within the bit length of this type.
Sourcepub const fn try_new(
value: <BitLength<8> as AssociatedStorage>::Storage,
) -> Option<Self>
pub const fn try_new( value: <BitLength<8> as AssociatedStorage>::Storage, ) -> Option<Self>
creates a new instance of this bitfield type with the given value.
if the value does not fit within the bit length of this type, returns None.
Sourcepub const unsafe fn new_unchecked(
value: <BitLength<8> as AssociatedStorage>::Storage,
) -> Self
pub const unsafe fn new_unchecked( value: <BitLength<8> as AssociatedStorage>::Storage, ) -> Self
creates a new instance of this bitfield type with the given value, without checking that the value fits within the bit length of this type.
Safety
the provided value must fit within the bit length of this type.
Sourcepub const fn get(&self) -> <BitLength<8> as AssociatedStorage>::Storage
pub const fn get(&self) -> <BitLength<8> as AssociatedStorage>::Storage
returns the inner value.