pub struct SB24(/* private fields */);Expand description
a type used to represent a field with a specific amount of bits.
Implementations
Sourceimpl SB24
impl SB24
pub const fn from_fields(fields: Self) -> Self
pub const fn to_fields(x: Self) -> Self
pub const fn try_from_bits( bits: <BitLength<24> as AssociatedStorage>::Storage, ) -> Option<Self>
pub const fn from_bits( bits: <BitLength<24> as AssociatedStorage>::Storage, ) -> Self
pub const fn to_bits(self) -> <BitLength<24> as AssociatedStorage>::Storage
pub const fn const_eq(a: Self, b: Self) -> bool
Sourceimpl SB24
impl SB24
Sourcepub const fn new(
value: <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed,
) -> Self
pub const fn new( value: <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed, ) -> Self
creates a new instance of this bitfield type with the given value.
this function panics if the value does not fit within the bit length of this type.
Sourcepub const fn try_new(
value: <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed,
) -> Option<Self>
pub const fn try_new( value: <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed, ) -> Option<Self>
creates a new instance of this bitfield type with the given value.
if the value does not fit within the bit length of this type, returns None.
Sourcepub const unsafe fn new_unchecked(
value: <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed,
) -> Self
pub const unsafe fn new_unchecked( value: <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed, ) -> Self
creates a new instance of this bitfield type with the given value, without checking that the value fits within the bit length of this type.
Safety
the provided value must fit within the bit length of this type.
Sourcepub const fn get(
&self,
) -> <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed
pub const fn get( &self, ) -> <<BitLength<24> as AssociatedStorage>::Storage as BitStorage>::Signed
returns the inner value.